@@ -152,7 +152,7 @@ public:
                bool onSurface = true) const;
 
   // get the bounding box
-  virtual SBoundingBox3d bounds(bool fast = false) const;
+  virtual SBoundingBox3d bounds(bool fast = false);
 
   // get the oriented bounding box
   virtual SOrientedBoundingBox getOBB();
