@@ -1,10 +1,10 @@
 // Gmsh - Copyright (C) 1997-2014 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
-#ifndef _CVT_REMESH_H_
-#define _CVT_REMESH_H_
+#ifndef CVT_REMESH_H
+#define CVT_REMESH_H
 
 #include "Plugin.h"
 
