@@ -1,7 +1,7 @@
 // Gmsh - Copyright (C) 1997-2013 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
 #include "GmshGlobal.h"
 #include "GmshConfig.h"
@@ -12,7 +12,7 @@
 #include "CurvedBndDist.h"
 
 #if defined(HAVE_OPTHOM)
-#include "OptHomIntegralBoundaryDist.h"
+#include "IntegralBoundaryDist.h"
 #endif
 
 extern "C" {
